@@ -1,5 +1,5 @@
 
-`_renv_root` <- NULL
+the$root <- NULL
 
 renv_paths_override <- function(name) {
 
@@ -40,13 +40,8 @@ renv_paths_common <- function(name, prefixes = NULL, ...) {
   else
     root
 
-  file.path(prefixed, ...) %||% ""
-
-}
-
-renv_paths_project <- function(..., project = NULL) {
-  project <- renv_project_resolve(project)
-  file.path(project, ...) %||% ""
+  path <- file.path(prefixed, ...)
+  if (length(path)) path else ""
 }
 
 renv_paths_library_root <- function(project) {
@@ -159,7 +154,7 @@ renv_paths_cache <- function(..., version = NULL) {
   renv_paths_common("cache", c(version, platform), ...)
 }
 
-renv_paths_rtools <- function(...) {
+renv_paths_rtools <- function() {
 
   root <- renv_paths_override("rtools")
   if (is.null(root)) {
@@ -167,8 +162,7 @@ renv_paths_rtools <- function(...) {
     root <- spec$root
   }
 
-  file.path(root, ...) %||% ""
-
+  root %||% ""
 }
 
 renv_paths_extsoft <- function(...) {
@@ -192,7 +186,7 @@ renv_paths_root <- function(...) {
 # nocov start
 renv_paths_root_default <- function() {
 
-  `_renv_root` <<- `_renv_root` %||% {
+  (the$root <- the$root %||% {
 
     # use tempdir for cache when running tests
     # this check is necessary here to support packages which might use renv
@@ -205,7 +199,7 @@ renv_paths_root_default <- function() {
     else
       renv_paths_root_default_impl()
 
-  }
+  })
 
 }
 
@@ -281,11 +275,10 @@ renv_paths_root_default_tempdir <- function() {
 
 # nocov end
 
-#' Path Customization
+#' Path for storing global state
 #'
-#' Access the paths that `renv` uses for global state storage.
-#'
-#' By default, `renv` collects state into these folders:
+#' @description
+#' By default, renv stores global state in the following OS-specific folders:
 #'
 #' \tabular{ll}{
 #' **Platform** \tab **Location** \cr
@@ -294,24 +287,12 @@ renv_paths_root_default_tempdir <- function() {
 #' Windows      \tab `%LOCALAPPDATA%/R/cache/R/renv` \cr
 #' }
 #'
-#' Note that older version of `renv` used a different default cache location.
-#' Those cache locations are:
-#'
-#' \tabular{ll}{
-#' **Platform** \tab **Location** \cr
-#' Linux        \tab `~/.local/share/renv` \cr
-#' macOS        \tab `~/Library/Application Support/renv` \cr
-#' Windows      \tab `%LOCALAPPDATA%/renv` \cr
-#' }
-#'
-#' If an `renv` root directory has already been created in one of the old
-#' locations, that will still be used. This change was made to comply with the
-#' CRAN policy requirements of \R packages.
-#'
 #' If desired, this path can be customized by setting the `RENV_PATHS_ROOT`
 #' environment variable. This can be useful if you'd like, for example, multiple
 #' users to be able to share a single global cache.
 #'
+#' # Customising individual paths
+#'
 #' The various state sub-directories can also be individually adjusted, if so
 #' desired (e.g. you'd prefer to keep the cache of package installations on a
 #' separate volume). The various environment variables that can be set are
@@ -324,25 +305,32 @@ renv_paths_root_default_tempdir <- function() {
 #' \code{RENV_PATHS_LIBRARY_ROOT}    \tab The parent path for project libraries. \cr
 #' \code{RENV_PATHS_LIBRARY_STAGING} \tab The parent path used for staged package installs. \cr
 #' \code{RENV_PATHS_SANDBOX}         \tab The path to the sandboxed \R system library. \cr
-#' \code{RENV_PATHS_LOCKFILE}        \tab The path to the [lockfile][lockfiles]. \cr
+#' \code{RENV_PATHS_LOCKFILE}        \tab The path to the [lockfile]. \cr
 #' \code{RENV_PATHS_CELLAR}          \tab The path to the cellar, containing local package binaries and sources. \cr
 #' \code{RENV_PATHS_SOURCE}          \tab The path containing downloaded package sources. \cr
 #' \code{RENV_PATHS_BINARY}          \tab The path containing downloaded package binaries. \cr
 #' \code{RENV_PATHS_CACHE}           \tab The path containing cached package installations. \cr
 #' \code{RENV_PATHS_PREFIX}          \tab An optional prefix to prepend to the constructed library / cache paths. \cr
+#' \code{RENV_PATHS_RENV}            \tab The path to the project's renv folder. For advanced users only. \cr
 #' \code{RENV_PATHS_RTOOLS}          \tab (Windows only) The path to [Rtools](https://cran.r-project.org/bin/windows/Rtools/). \cr
 #' \code{RENV_PATHS_EXTSOFT}         \tab (Windows only) The path containing external software needed for compilation of Windows source packages. \cr
 #' \code{RENV_PATHS_MRAN}            \tab The path containing MRAN-related metadata. See `vignette("mran", package = "renv")` for more details. \cr
 #' }
 #'
-#' Note that `renv` will append platform-specific and version-specific entries
+#' (If you want these settings to persist in your project, it is recommended that
+#' you add these to an appropriate \R startup file. For example, these could be
+#' set in: a project-local `.Renviron`, the user-level `.Renviron`, or a
+#' site-wide file at `file.path(R.home("etc"), "Renviron.site")`. See
+#' [Startup] for more details).
+#'
+#' Note that renv will append platform-specific and version-specific entries
 #' to the set paths as appropriate. For example, if you have set:
 #'
 #' ```
 #' Sys.setenv(RENV_PATHS_CACHE = "/mnt/shared/renv/cache")
 #' ```
 #'
-#' then the directory used for the cache will still depend on the `renv` cache
+#' then the directory used for the cache will still depend on the renv cache
 #' version (e.g. `v2`), the \R version (e.g. `3.5`) and the platform (e.g.
 #' `x86_64-pc-linux-gnu`). For example:
 #'
@@ -354,10 +342,17 @@ renv_paths_root_default_tempdir <- function() {
 #' globally without worry that it may cause collisions or errors if multiple
 #' versions of \R needed to interact with the same cache.
 #'
+#' If reproducibility of a project is desired on a particular machine, it is
+#' highly recommended that the renv cache of installed packages + binary
+#' packages is backed up and persisted, so that packages can be easily restored
+#' in the future -- installation of packages from source can often be arduous.
+#'
+#' # Sharing state across operating systems
+#'
 #' If you need to share the same cache with multiple different Linux operating
 #' systems, you may want to set the `RENV_PATHS_PREFIX` environment variable
 #' to help disambiguate the paths used on Linux. For example, setting
-#' `RENV_PATHS_PREFIX = "ubuntu-bionic"` would instruct `renv` to construct a
+#' `RENV_PATHS_PREFIX = "ubuntu-bionic"` would instruct renv to construct a
 #' cache path like:
 #'
 #' ```
@@ -369,7 +364,7 @@ renv_paths_root_default_tempdir <- function() {
 #' located at `file.path(R.home("etc"), "Renviron.site")`, so that it can be
 #' active for any \R sessions launched on that machine.
 #'
-#' Starting from `renv 0.13.0`, you can also instruct `renv` to auto-generate
+#' Starting from `renv 0.13.0`, you can also instruct renv to auto-generate
 #' an OS-specific component to include as part of library and cache paths,
 #' by setting the environment variable:
 #'
@@ -380,25 +375,10 @@ renv_paths_root_default_tempdir <- function() {
 #' The prefix will be constructed based on fields within the system's
 #' `/etc/os-release` file.
 #'
-#' If reproducibility of a project is desired on a particular machine, it is
-#' highly recommended that the `renv` cache of installed packages + binary
-#' packages is backed up and persisted, so that packages can be easily restored
-#' in the future -- installation of packages from source can often be arduous.
-#'
-#' If you want these settings to persist in your project, it is recommended that
-#' you add these to an appropriate \R startup file. For example, these could be
-#' set in:
-#'
-#' - A project-local `.Renviron`;
-#' - The user-level `.Renviron`;
-#' - A file at `file.path(R.home("etc"), "Renviron.site")`.
-#'
-#' Please see ?[Startup] for more details.
-#'
-#' @section Package Cellar:
+#' # Package cellar
 #'
 #' If your project depends on one or \R packages that are not available in any
-#' remote location, you can still provide a locally-available tarball for `renv`
+#' remote location, you can still provide a locally-available tarball for renv
 #' to use during restore. By default, these packages should be made available in
 #' the folder as specified by the `RENV_PATHS_CELLAR` environment variable. The
 #' package sources should be placed in a file at one of these locations:
@@ -409,29 +389,31 @@ renv_paths_root_default_tempdir <- function() {
 #' - `<project>/renv/cellar/<package>/<package>_<version>.<ext>`
 #'
 #' where `.<ext>` is `.tar.gz` for source packages, or `.tgz` for binaries on
-#' macOS and `.zip` for binaries on Windows. During `restore()`, `renv` will
+#' macOS and `.zip` for binaries on Windows. During `restore()`, renv will
 #' search the cellar for a compatible package, and prefer installation with
 #' that copy of the package if appropriate.
 #'
-#' @section Projects:
+#' # Older versions
 #'
-#' In order to determine whether a package can safely be removed from the cache,
-#' `renv` needs to know which projects are using packages from the cache. Since
-#' packages may be symlinked from the cache, and symlinks are by nature a one-way
-#' link, projects need to also report that they're using the `renv` cache.
+#' Older version of renv used a different default cache location.
+#' Those cache locations are:
 #'
-#' To accomplish this, whenever `renv` is used with a project, it will record
-#' itself as being used within a file located at:
+#' \tabular{ll}{
+#' **Platform** \tab **Location** \cr
+#' Linux        \tab `~/.local/share/renv` \cr
+#' macOS        \tab `~/Library/Application Support/renv` \cr
+#' Windows      \tab `%LOCALAPPDATA%/renv` \cr
+#' }
 #'
-#' - `${RENV_PATHS_ROOT}/projects`
-#'
-#' This file is list of projects currently using the `renv` cache. With this,
-#' `renv` can crawl projects registered with `renv` and use that to determine if
-#' any packages within the cache are no longer in use, and can be removed.
+#' If an renv root directory has already been created in one of the old
+#' locations, that will still be used. This change was made to comply with the
+#' CRAN policy requirements of \R packages.
 #'
 #' @rdname paths
 #' @name paths
 #'
+#' @format NULL
+#'
 #' @export
 #'
 #' @examples
