@@ -1,24 +1,31 @@
-#' Generate renv Project Infrastructure
+#' Generate project infrastructure
 #'
-#' Write the `renv` project infrastructure for a project.
+#' @description
+#' Create the renv project infrastructure. This will:
 #'
-#' Invoking `renv::scaffold()` will:
+#' - Create a project library, `renv/library`.
 #'
-#' - Install `renv` into the project library,
+#' - Install renv into the project library.
 #'
-#' - Update the project `.Rprofile` so that `renv` is automatically loaded
-#'   for new \R sessions launched in this project, and
+#' - Update the project `.Rprofile` to call `source("renv/activate.R")` so
+#'   that renv is automatically loaded for new \R sessions launched in
+#'   this project.
 #'
-#' - Write a bare lockfile `renv.lock`.
+#' - Create `renv/.gitignore`, which tells git to ignore the project library.
+#'
+#' - Create `.Rbuildignore`, if the project is also a package. This tells
+#'   `R CMD build` to ignore the renv infrastructure,
+#'
+#' - Write a (bare) [lockfile], `renv.lock`.
 #'
 #' @inheritParams renv-params
 #'
-#' @param version The version of `renv` to associate with this project. By
-#'   default, the version of `renv` currently installed is used.
+#' @param version The version of renv to associate with this project. By
+#'   default, the version of renv currently installed is used.
 #'
 #' @param repos The \R repositories to associate with this project.
 #'
-#' @param settings A list of `renv` settings, to be applied to the project
+#' @param settings A list of renv settings, to be applied to the project
 #'   after creation. These should map setting names to the desired values.
 #'   See [settings] for more details.
 #'
@@ -55,15 +62,14 @@ scaffold <- function(project  = NULL,
   lockfile <- renv_lockfile_create(
     project  = project,
     libpaths = renv_paths_library(project = project),
-    type     = "implicit",
-    packages = NULL
+    type     = "implicit"
   )
 
   renv_lockfile_write(lockfile, file = renv_lockfile_path(project))
 
   # notify user
-  fmt <- "* renv infrastructure has been generated for project %s."
-  vwritef(fmt, renv_path_pretty(project))
+  fmt <- "- renv infrastructure has been generated for project %s."
+  writef(fmt, renv_path_pretty(project))
 
   # return project invisibly
   invisible(project)
